<?php

namespace Intergo\AnalyticsClient;

use Intergo\BaseClient\Responses\BaseResponseInterface;

class AnalyticsService
{
    /** @var string */
    public $baseUrl;

    /** @var AnalyticsClient */
    private $client;

    /**
     * AnalyticsService constructor.
     *
     * @param string $baseUrl
     */
    public function __construct($baseUrl)
    {
        $this->baseUrl = $baseUrl;
        $this->client = new AnalyticsClient();
    }

    /**
     * @param string $endpoint
     * @param array $params
     * @return BaseResponseInterface
     */
    protected function execute(string $endpoint, array $params): BaseResponseInterface
    {
        return $this->client->execute($endpoint, $this->baseUrl, $params);
    }

    /**
     * Send events to our "service-analytics" (https://github.com/intergo/service-analytics).
     *
     * @see https://app.asana.com/0/1202041647164570/1203587484023149/f
     * @param int|string $client_id
     * @param int $user_id
     * @param array $events
     * @return BaseResponseInterface
     * @throws \Exception
     */
    public function send($client_id, $user_id, array $events = [])
    {
        return $this->execute(__FUNCTION__, get_defined_vars());
    }
}
